SystemOrganization addCategory: #ConfigurationOfMetacello!

Object subclass: #ConfigurationOfMetacello
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfMetacello'!

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 6/12/2012 09:37:55.692'!
alternateEnsureMetacello
	"Use this method if the primary repository 'http://seaside.gemstone.com/ss/metacello' is inaccessible.
	 Secondary repository is valid for loading versions 1.0-beta.26 and later. "

	self deprecated: 'current version of #ensureMetacello automatically tries to load using alternate repository'.
	Smalltalk at: #MetacelloProject  ifAbsent: [  
		self ensureGoferVersion: 'Gofer-Core-lr.115'.
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer version repo |
			gofer := goferClass new
				url: 'http://www.squeaksource.com/metacello';
				version: 'Metacello-Core-DaleHenrichs.348';
				version: 'Metacello-MC-DaleHenrichs.332';
				yourself.
			Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString  |
				versionString := cl current version.
				(versionString beginsWith: 'Squeak3')
					ifTrue: [ gofer version: 'Metacello-Platform.squeak-dkh.5']].
			gofer load.
			"now load minimal installation from alternate repository"
			version := self project latestVersion.
			repo := MCHttpRepository 
				location: 'http://www.squeaksource.com/metacello' 
				user: '' 
				password: ''.
			(version repositoryOverrides: (Array with: (repo))) load ]]! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
backupToSqueakSource
	"In order for username and password to be set correctly, you must already have the metacello repository
	 set up"

	| cacheRepository version |
	cacheRepository := MCHttpRepository location: 'http://www.squeaksource.com/metacello' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	cacheRepository := MCRepositoryGroup default repositories
		detect: [ :each | each = cacheRepository ]
		ifNone: [ cacheRepository ].
	version := self project latestVersion.
	version ignoreImage: true.
	(version record: 'ALL') loadDirective
		versionDirectivesDo: [ :versionDirective | 
			| p pClass |
			versionDirective spec ~~ nil
				ifTrue: [ 
					p := versionDirective spec project.
					pClass := p configuration class.	"save packages for Gofer and Metacello only"
					(pClass == (Smalltalk at: #ConfigurationOfGofer) or: [ pClass == self ])
						ifTrue: [ 
							| policy |
							policy := ((Smalltalk at: #MetacelloLoaderPolicy) new)
								cacheRepository: cacheRepository;
								ignoreImage: true;
								yourself.	"fetch Gofer or Metacello configuration"
							p fetchProject: policy.
							versionDirective
								packagesDo: [ :packageDirective | 
									"skip nested configurations"
									(packageDirective spec name beginsWith: 'ConfigurationOf')
										ifFalse: [ 
											"fetch mcz file"
											packageDirective spec fetchPackage: policy ] ] ] ] ]
					! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 9/14/2012 15:23'!
bootstrapMetacelloFrom: repositoryUrl
    "Corresponds to version 1.0-beta.31.1.5"

    | minimumPackages |
    self ensureGoferVersion: 'Gofer-Core-lr.115' repositoryUrl: repositoryUrl.
    minimumPackages := OrderedCollection
        withAll: #('Metacello-Base-DaleHenrichs.19' 'Metacello-Core-dkh.492' 'Metacello-MC-dkh.664').
    self platformPackage ifNotNil: [ :pkg | minimumPackages add: pkg ].
    minimumPackages do: [ :pkg | self bootstrapPackage: pkg from: repositoryUrl ]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := (MCCacheRepository default includesVersionNamed: aString)
		ifTrue: [MCCacheRepository default]
		ifFalse: [MCHttpRepository
				location: aPath
				user: ''
				password: ''].
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
copyConfigToRepos
	"In order for username and password to be set correctly, you must already have the MetacelloRepository
	 (on GemSource) repository set up"

	| targetRepository1 targetRepository2 gofer version |
	targetRepository1 := MCHttpRepository location: 'http://www.squeaksource.com/MetacelloRepository' user: '' password: ''.

	targetRepository2 := MCHttpRepository location: 'http://seaside.gemstone.com/ss/MetacelloRepository' user: '' password: ''.
	"need to pick up existing repository with user and password set"
	targetRepository2 := MCRepositoryGroup default repositories
		detect: [ :each | each = targetRepository2 ]
		ifNone: [ targetRepository2 ].

	gofer := (Smalltalk at: #Gofer) new
		gemsource: 'metacello';
		package: 'ConfigurationOfMetacello'.
	version := gofer resolved first version.
	(Array with: targetRepository1 with: targetRepository2) do: [:repo | repo storeVersion: version ]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureCoreMetacello
    "Bootstrap Metacello and load the minimum support"

    self ensureMetacello: #('Metacello-Core')! !

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureGoferVersion: goferVersion
	"load the p=file goferVersion if Gofer isn't loaded or an earlier version of Gofer is currently loaded"
	
	 | goferVersionNumber goferRepository wc pName |
	self deprecated: 'Use #ensureGoferVersion:repositoryUrl: instead ... '.
	goferRepository := 'http://seaside.gemstone.com/ss/metacello'.
	(Smalltalk at: #Gofer ifAbsent: []) == nil
		ifTrue: [ ^self bootstrapPackage: goferVersion from: goferRepository ].
	goferVersionNumber := (goferVersion copyAfterLast: $.) asNumber.
	wc := [ ((Smalltalk at: #GoferPackageReference) name: 'Gofer') workingCopy ]
			on: Error
			do: [:ex | ex return: ((Smalltalk at: #GoferPackageReference) name: 'Gofer-Core') workingCopy ].
	pName := wc ancestry ancestors first name.
	(pName copyAfterLast: $.) asNumber <= goferVersionNumber
		ifTrue: [ self bootstrapPackage: goferVersion from: goferRepository ]
! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureGoferVersion: goferVersion repositoryUrl: repositoryUrl
	"load the p=file goferVersion if Gofer isn't loaded or an earlier version of Gofer is currently loaded"
	
	 | goferVersionNumber wc pName |
	(Smalltalk at: #Gofer ifAbsent: []) == nil
		ifTrue: [ ^self bootstrapPackage: goferVersion from: repositoryUrl ].
	goferVersionNumber := (goferVersion copyAfterLast: $.) asNumber.
	wc := [ ((Smalltalk at: #GoferPackageReference) name: 'Gofer') workingCopy ]
			on: Error
			do: [:ex | ex return: ((Smalltalk at: #GoferPackageReference) name: 'Gofer-Core') workingCopy ].
	pName := wc ancestry ancestors first name.
	(pName copyAfterLast: $.) asNumber <= goferVersionNumber
		ifTrue: [ self bootstrapPackage: goferVersion from: repositoryUrl ]
! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'SeanDeNigris 6/22/2012 11:38'!
ensureMetacello
    "Bootstrap Metacello and load the 'default' group"

    self ensureMetacello: #('batch')! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'dkh 6/12/2012 09:37:55.692'!
ensureMetacello: loadList
    "Bootstrap Metacello, retry using alternate repository, if primary repository is not accessible"

    Smalltalk
        at: #'MetacelloProject'
        ifAbsent: [ 
            | retry version error |
            retry := false.
            (Array with: 'http://seaside.gemstone.com/ss/metacello' with: 'http://www.squeaksource.com/metacello')
                do: [ :repositoryUrl | 
                    [ 
                    "bootstrap Metacello"
                    self bootstrapMetacelloFrom: repositoryUrl.	"load latest version of Metacello"
                    version := self project latestVersion.
                    retry
                        ifTrue: [ 
                            "on retry, use #repositoryOverrides:"
                            version
                                repositoryOverrides:
                                    (Array with: (MCHttpRepository location: repositoryUrl user: '' password: '')) ].
                    version load: loadList.
                    ^ self ]
                        on: Error
                        do: [ :ex | 
                            error := ex.
                            Transcript
                                cr;
                                show: 'failed ensureMetacello: ';
                                show: ex description printString;
                                show: '...retrying'.	"try again"
                            retry := true.
                            ex return: nil ] ].	"shouldn't get here unless the load failed ... throw an error"
            self error: 'retry with alternate repository failed: ' , error description printString ]! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpGettingStarted
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'To get started, install Metacello and see the ''Getting Started'' section in the Metacello chapter of the Help Browser:';
		cr; tab; nextPutAll: 'HelpBrowser openOn: ((Smalltalk at: #MetacelloHelp) perform:  #asHelpTopic)';
		cr;cr;nextPutAll: 'It is also recommended that you install the Metacello Browser,. For information see';
		cr; tab; nextPutAll: 'http://metacellobrowser.dcc.uchile.cl/'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Getting Started' with: stream contents
! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpInstallation
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'To install the core functionality of Metacello, execute the following expression:';
		cr; tab; nextPutAll: 'ConfigurationOfMetacello load.';
		cr;cr;nextPutAll: 'To install the tutorial (recommended), execute the following expression:';
		cr; tab; nextPutAll: '(ConfigurationOfMetacello project version: #stable) load: #(''Tutorial'').'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Installing' with: stream contents
! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpIntro
	| stream |
	stream := WriteStream on: String new.
	stream
		nextPutAll: 'Metacello is a package management system for Monticello';
		cr;cr;nextPutAll: 'Metacello Browser is written and maintained by:';
		cr;tab;nextPutAll: 'Dale Henrichs';
		cr;cr;nextPutAll: 'To submit bug reports, visit the following link:';
		cr;tab;nextPutAll: 'http://code.google.com/p/metacello/issues/entry';
		cr;cr;nextPutAll: 'For additional info see the Metacello project site:';
		cr;tab;nextPutAll: 'http://code.google.com/p/metacello/'.
	^ (Smalltalk at: #HelpTopic) perform: #title:contents: with: 'Introduction' with: stream contents! !

!ConfigurationOfMetacello class methodsFor: 'help' stamp: 'dkh 6/12/2012 09:37:55.692'!
helpPages
	| pages |
	pages := {#helpIntro. #helpInstallation. #helpGettingStarted}.
	"include MetacelloHelp if installed"
	Smalltalk at: #MetacelloHelp ifPresent: [ :cl | pages :=  pages , {cl} ].
	^ pages! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
isMetacelloConfig

	^true! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'SeanDeNigris 6/27/2012 14:25'!
load
	"Load a minimum installation of Metacello"

	"self load"

	^ self project latestVersion load: 'batch'.! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
loadLatestPackages
	"self loadLatestPackages"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	| project |
	project := self project.
	^(project latestVersion: #baseline) load: #( 'default' 'Metacello-Tutorial')! !

!ConfigurationOfMetacello class methodsFor: 'loading' stamp: 'dkh 6/12/2012 09:37:55.692'!
loadLatestVersion
	"self loadLatestVersion"

	self project updateProject.
	^self project latestVersion load! !

!ConfigurationOfMetacello class methodsFor: 'metacello tool support' stamp: 'dkh 6/12/2012 09:37:55.692'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfMetacello class methodsFor: 'deprecated' stamp: 'dkh 6/12/2012 09:37:55.692'!
oldEnsureMetacello
	"original implementation of ensureMetacello, just in case problems surface."

	self deprecated: 'use #ensureMetacello instead'.
	Smalltalk at: #MetacelloProject  ifAbsent: [  
		self ensureGoferVersion: 'Gofer-Core-lr.115'.
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				version: 'Metacello-Core-DaleHenrichs.348';
				version: 'Metacello-MC-DaleHenrichs.332';
				yourself.
			Smalltalk at: #SystemVersion ifPresent: [:cl | | versionString |
				versionString := cl current version.
				(versionString beginsWith: 'Squeak3')
					ifTrue: [ gofer version: 'Metacello-Platform.squeak-dkh.5']].
			gofer load.
			"now load minimal installation"
			self load ]]! !

!ConfigurationOfMetacello class methodsFor: 'private' stamp: 'SeanDeNigris 6/27/2012 23:06'!
platformPackage

	Smalltalk at: #SystemVersion ifPresent: [ :sysVersion | | versionString |
		versionString := sysVersion current version.

		(versionString beginsWith: 'Squeak') ifTrue: [ 
			^ (versionString beginsWith: 'Squeak3')
				ifTrue: [ 'Metacello-Platform.squeak-dkh.5' ]
				ifFalse: [ 'Metacello-Platform.squeak-dkh.10' ] ].
		
		(versionString beginsWith: 'Pharo') ifTrue: [ 
			^ (versionString beginsWith: 'Pharo2')
				ifTrue: [ 'Metacello-Platform.pharo20-SeanDeNigris.28' ]
				ifFalse: [ 'Metacello-Platform.pharo-dkh.27' ] ] ].
	^ nil.! !

!ConfigurationOfMetacello class methodsFor: 'accessing' stamp: 'dkh 6/12/2012 09:37:55.692'!
project

	^self new project! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
releaseDevelopmentVersion: commitMessage
	"Release #development version: set version blessing to #release, update the #development and #stable symbolic version methods and save the configuration."

	"self releaseDevelopmentVersion: '- release version 1.0-beta.28.3'"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) releaseDevelopmentVersionIn: self description: commitMessage! !

!ConfigurationOfMetacello class methodsFor: 'metacello release process' stamp: 'dkh 6/12/2012 09:37:55.692'!
releaseMetacelloVersion
	"self releaseMetacelloVersion"
	
	self 
		copyConfigToRepos;
		backupToSqueakSource;
		yourself! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
saveModifiedPackagesAndConfiguration: commitMessage
	"Save modified mcz files, update and then save the configuration."

	"self saveModifiedPackagesAndConfiguration: '- fixed bug'"

	"Note that Metacello 1.0-beta.28 is needed and is currently unstable and in development"

	<apiDocumentation>
	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) saveModifiedPackagesAndConfigurationIn: self description: commitMessage! !

!ConfigurationOfMetacello class methodsFor: 'unloading' stamp: 'dkh 6/12/2012 09:37:55.692'!
unloadMetacello

	| gofer |
	gofer := Gofer new.
	MCWorkingCopy allManagers do: [:wc |
		((wc packageName beginsWith: 'Metacello') or: [ wc packageName beginsWith: 'OB-Metacello' ])
			ifTrue: [ gofer package: wc packageName ]].
	gofer unload.! !

!ConfigurationOfMetacello class methodsFor: 'development support' stamp: 'dkh 6/12/2012 09:37:55.692'!
validate
    "self validate"

    self ensureMetacello.
    ^ ((Smalltalk at: #'MetacelloToolBox') validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta00: spec 
	<version: '1.0-beta.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Default configuration ... loads latest versions of all packages'.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/flair' ];
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform') ];
			package: 'Metacello-MC' with: [
				spec requires: #('Gofer') ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ConfigTests' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC') ];
			package: 'Metacello-ReferenceTests' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform') ].
		spec
			group: 'default' with: #('Metacello-Core' 'Metacello-Reference');
			group: 'UI' with: #('Metacello-Core' 'OB-Metacello'); 
			group: 'Tests' with: #('Metacello-ConfigTests' 'Metacello-ReferenceTests') ].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone'].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo'].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak' ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta03: spec 
	<version: '1.0-beta.3-baseline' imports: #('1.0-beta.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.0-baseline: 
- ''default'' group is just the core ... class-side loaders load ''ALL'' by default
- pull in some old tests that still apply
- combine Metacello-ConfigTests into Metacello-TestsMC
- rename Metacello-ReferenceTests to Metacello-TestsReference
- recast tutorial to new API
- add Samples group (Metacello-Configuration [duh] and Seaside-Metacello-Configuration'.

		spec 
			package: 'Metacello-Tutorial' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsCore' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsMC' with: [
				spec requires:  #('Metacello-Core'). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference') ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires:  #('Metacello-Tutorial'). ];
			removePackage: 'Metacello-ConfigTests';
			removePackage: 'Metacello-ReferenceTests';
			"SAMPLE"
			package: 'ConfigurationOfMetacello' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			"SAMPLE"
			package: 'Seaside-Metacello-Configuration' with: [
				spec repository: 'http://seaside.gemstone.com/ss/Seaside30' ].
		spec
			group: 'default' overrides: #('Metacello-Core');
			group: 'Samples' with: #('ConfigurationOfMetacello' 'Seaside-Metacello-Configuration');
			group: 'Tests' overrides: 
				#('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC'
				  'Metacello-TestsReference'). ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta05: spec 
	<version: '1.0-beta.5-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Extensions to 1.0-beta.3-baseline: 
- Samples group includes Seaside-Metacello-Configuration and GemTools-Configuraton (Metacello-Configuration should not be included ... it is always present)'.

		spec 
			package: 'GemTools-Configuraton' with: [
				spec repository: 'http://seaside.gemstone.com/ss/GLASSClient' ];
			removePackage: 'ConfigurationOfMetacello'.
		spec
			group: 'Samples' overrides: 
				#('Seaside-Metacello-Configuration' 'GemTools-Configuraton' ) ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta11: spec 
	<version: '1.0-beta.11-baseline' imports: #('1.0-beta.3-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'Removing Samples completely... Confusing I think'.

		spec 
			removePackage: 'Seaside-Metacello-Configuration';
			removePackage: 'GemTools-Configuraton';
			removePackage: 'ConfigurationOfMetacello'.
		spec
			removeGroup: 'Samples'].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta13: spec 
	<version: '1.0-beta.13-baseline' imports: #('1.0-beta.11-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'fix Metacello-MC dependency'.

		spec 
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core') ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta14: spec 
	<version: '1.0-beta.14-baseline' imports: #('1.0-beta.13-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://source.lukas-renggli.ch/gofer' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta16: spec 
	<version: '1.0-beta.16-baseline' imports: #('1.0-beta.14-baseline')>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec description: 'switch gofer repositories again ... use copy in Metacello going forward'.

		spec 
			package: 'Gofer' with: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			yourself].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta17: spec 
	<version: '1.0-beta.17-baseline' imports: #('1.0-beta.16-baseline')>
	
	spec for: #squeakCommon do: [
		spec 
			package: 'Metacello-TestsPlatform' with: [
				spec
					requires: #('Metacello-Platform');
					file: 'Metacello-TestsPlatform.squeakCommon'];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform')].
		
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta18: spec 
	<version: '1.0-beta.18-baseline' imports: #('1.0-beta.17-baseline')>
	
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Gofer' with: [
				spec requires: #('Monticello')];
			yourself. ].
		
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta19: spec 
	<version: '1.0-beta.19-baseline' imports: #('1.0-beta.18-baseline')>

	spec for: #'Gofer-Core' do: [
		spec
			removePackage: 'Gofer';
			package: 'Gofer-Core'  with: [
				spec repository: 'http://www.squeaksource.com/Pharo' ];
			package: 'Gofer-Tests'  with: [
				spec repository: 'http://www.squeaksource.com/Pharo' ];
			package: 'Metacello-MC' overrides: [
				spec requires: #('Gofer-Core') ];
			package: 'Metacello-TestsMC' with: [
				spec requires: #('Gofer-Tests') ];
			yourself ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta21: spec 
	<version: '1.0-beta.21-baseline' imports: #('1.0-beta.19-baseline')>

	spec for: #'Gofer-Core' do: [
		spec
			removePackage: 'Gofer';
			package: 'Gofer-Core'  overrides: [
				spec repository: 'http://seaside.gemstone.com/ss/metacello' ];
			package: 'Gofer-Tests'  overrides: [
				spec 
					requires: 'Gofer-Core' ;
					repository: 'http://seaside.gemstone.com/ss/metacello' ];
			yourself ].
! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta22: spec
	<version: '1.0-beta.22-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta25: spec
	<version: '1.0-beta.25-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta27: spec
	<version: '1.0-beta.27-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Core' with: [
				spec includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta2831: spec
	<version: '1.0-beta.28.3.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta2833: spec
	<version: '1.0-beta.28.3.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28: spec
	<version: '1.0-beta.28-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28ea3: spec
	<version: '1.0-beta.28-ea.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta28ea: spec
	<version: '1.0-beta.28-ea-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' ). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' overrides: #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			group: 'Tutorial' with: #('Metacello-Help' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta29: spec
	<version: '1.0-beta.29-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone';
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta30: spec
	<version: '1.0-beta.30-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: 'Metacello-Base'. ];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/monticello' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'SeanDeNigris 6/22/2012 11:41'!
baseline10beta3113: spec
	<version: '1.0-beta.31.1.3-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'batch' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'SeanDeNigris 6/27/2012 22:15'!
baseline10beta3114: spec
	<version: '1.0-beta.31.1.4-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'batch' with: #('Metacello-Core' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://dsal.cl/squeaksource/MetacelloRepository'. ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo2.x' do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20';
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 9/14/2012 18:47'!
baseline10beta3115: spec
    <version: '1.0-beta.31.1.5-baseline'>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'baseline'.
            spec repository: 'http://seaside.gemstone.com/ss/metacello'.
            spec repository: 'http://www.squeaksource.com/metacello'.
            spec
                project: 'Gofer Core'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGofer';
                                versionString: '1.0-baseline';
                                loads: #('Core');
                                file: 'ConfigurationOfGofer';
                                repository: 'http://www.squeaksource.com/MetacelloRepository';
                                repository: 'http://seaside.gemstone.com/ss/metacello' ];
                project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [ spec loads: #('Tests') ];
                yourself.
            spec
                package: 'Metacello-Base';
                package: 'Metacello-ToolBox' with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
                package: 'Metacello-Core'
                    with: [ 
                            spec
                                requires: 'Metacello-Base';
                                includes: #('Metacello-MC' 'Metacello-Platform') ];
                package: 'Metacello-MC' with: [ spec requires: #('Metacello-Core' 'Gofer Core') ];
                package: 'Metacello-Platform' with: [ spec requires: #('Metacello-MC') ];
                package: 'Metacello-Reference' with: [ spec requires: #('Metacello-MC') ];
                package: 'Metacello-Tutorial' with: [ spec requires: #('Metacello-Core') ];
                package: 'Metacello-TestsCore' with: [ spec requires: #('Metacello-Core') ];
                package: 'Metacello-TestsMC'
                    with: [ 
                            spec
                                postLoadDoIt: #'testsMC10beta25PostLoadDoIt';
                                requires: #('Metacello-ToolBox' 'Metacello-MC' 'Gofer Tests') ];
                package: 'Metacello-TestsReference' with: [ spec requires: #('Metacello-Reference') ];
                package: 'Metacello-TestsTutorial' with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC') ];
                package: 'OB-Metacello'
                    with: [ spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox') ];
                yourself.
            spec
                group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox');
                group: 'batch' with: #('Metacello-Core');
                group: 'Base Configuration' with: #('Metacello-Base');
                group: 'Core' with: #('default');
                group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
                group: 'UI' with: #('OB-Metacello');
                group: 'TravisCI'
                    with:
                        #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
                group: 'Tests'
                    with:
                        #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
                yourself ].
    spec
        for: #'squeakCommon'
        do: [ 
            spec
                project: 'Help System'
                    with: [ 
                            spec
                                className: 'ConfigurationOfHelpSystem';
                                versionString: '1.0-baseline';
                                loads: #('Core');
                                file: 'ConfigurationOfHelpSystem';
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                project: 'OB'
                    with: [ 
                            spec
                                className: 'ConfigurationOfOmniBrowser';
                                versionString: '1.1-baseline';
                                loads: #('Core');
                                file: 'ConfigurationOfOmniBrowser';
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-TestsPlatform'
                    with: [ 
                            spec
                                requires: #('Metacello-Platform');
                                file: 'Metacello-TestsPlatform.squeakCommon' ];
                package: 'Metacello-Help' with: [ spec requires: 'Help System' ];
                package: 'OB-Metacello' with: [ spec requires: #('OB') ];
                yourself.
            spec
                group: 'default' with: #('Metacello-Help');
                group: 'TravisCI' with: #('Metacello-TestsPlatform');
                group: 'Tests' with: #('Metacello-TestsPlatform');
                yourself ].
    spec
        for: #'pharo'
        do: [ 
            spec
                project: 'ProfStef'
                    with: [ 
                            spec
                                className: 'ConfigurationOfProfStef';
                                versionString: '1.0-baseline';
                                file: 'ConfigurationOfProfStef';
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-ProfStef'
                    with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
                package: 'Metacello-TestsProfStef' with: [ spec requires: #('Metacello-ProfStef') ];
                package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
                yourself.
            spec
                group: 'Tests' with: #('Metacello-TestsProfStef');
                group: 'Tutorial' with: #('Metacello-ProfStef');
                yourself ].
    spec for: #'pharo1.0.x' do: [ spec package: 'Metacello-ProfStef' with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
    spec for: #'pharo1.1.x' do: [ spec package: 'Metacello-ProfStef' with: [ spec file: 'Metacello-ProfStef.toolset' ] ].
    spec
        for: #'pharo1.2.x'
        do: [ 
            spec
                package: 'Metacello-ProfStef' with: [ spec file: 'Metacello-ProfStef.toolset' ];
                package: 'Metacello-TestsMC' with: [ spec includes: #('Metacello-Issue3758') ];
                package: 'Metacello-Issue3758' with: [ spec requires: #('Metacello-TestsMC') ];
                yourself ].
    spec
        for: #'pharo1.3.x'
        do: [ 
            spec
                package: 'Metacello-TestsMC' with: [ spec includes: #('Metacello-Issue3758') ];
                package: 'Metacello-Issue3758' with: [ spec requires: #('Metacello-TestsMC') ];
                yourself ].
    spec
        for: #'pharo2.x'
        do: [ 
            spec
                package: 'Metacello-Platform' with: 'Metacello-Platform.pharo20';
                yourself ].
    spec
        for: #'squeak'
        do: [ 
            spec
                package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
                yourself ].
    spec
        for: #'gemstone'
        do: [ 
            spec
                project: 'Monticello'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGsMonticello';
                                repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
                project: 'OB'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGsOB';
                                repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-Platform'
                    with: [ 
                            spec
                                file: 'Metacello-Platform.gemstone';
                                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                                requires: 'Monticello' ];
                package: 'Metacello-TestsPlatform'
                    with: [ 
                            spec
                                requires: #('Metacello-Platform');
                                file: 'Metacello-TestsPlatform.gemstone' ];
                package: 'OB-Metacello' with: [ spec requires: #('OB') ];
                yourself.
            spec
                group: 'Tests' with: #('Metacello-TestsPlatform');
                group: 'TravisCI' with: #('Metacello-TestsPlatform');
                yourself ]! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta311: spec
	<version: '1.0-beta.31.1-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfGsOB';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					postLoadDoIt: #gemstone10beta311PostLoadDoIt;
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 6/12/2012 09:37:55.692'!
baseline10beta31: spec
	<version: '1.0-beta.31-baseline'>

	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec repository: 'http://www.squeaksource.com/metacello'.
		spec
			project: 'Gofer Core' with: [
				spec
					className: 'ConfigurationOfGofer';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfGofer';
					repository: 'http://www.squeaksource.com/MetacelloRepository';
					repository: 'http://seaside.gemstone.com/ss/metacello'. ];
			project: 'Gofer Tests' copyFrom: 'Gofer Core' with: [
				spec loads: #('Tests' ) ];
			yourself.
		spec 
			package: 'Metacello-Base';
			package: 'Metacello-ToolBox' with: [
				spec requires: #('Metacello-Base' 'Metacello-Core')];
			package: 'Metacello-Core' with: [
				spec 
					requires: 'Metacello-Base';
					includes: #('Metacello-MC' 'Metacello-Platform' ). ];
			package: 'Metacello-MC' with: [
				spec requires: #('Metacello-Core' 'Gofer Core' ). ];
			package: 'Metacello-Platform' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Reference' with: [
				spec requires: #('Metacello-MC' ). ];
			package: 'Metacello-Tutorial' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsCore' with: [
				spec requires: #('Metacello-Core' ). ];
			package: 'Metacello-TestsMC' with: [
				spec 
					postLoadDoIt: #testsMC10beta25PostLoadDoIt;
					requires: #('Metacello-MC' 'Gofer Tests' ). ];
			package: 'Metacello-TestsReference' with: [
				spec requires: #('Metacello-Reference' ). ];
			package: 'Metacello-TestsTutorial' with: [
				spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC' ). ];
			package: 'OB-Metacello' with: [
				spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox'). ];
			yourself.

		spec 
			group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' );
			group: 'Base Configuration' with: #('Metacello-Base' );
			group: 'Core' with: #('default' );
			group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference' );
			group: 'UI' with: #('OB-Metacello' );
			group: 'Tests' with: #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference' );
			yourself.].
	spec for: #squeakCommon do: [
		spec
			project: 'Help System' with: [
				spec
					className: 'ConfigurationOfHelpSystem';
					versionString: '1.0-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfHelpSystem';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			project: 'OB' with: [
				spec
					className: 'ConfigurationOfOmniBrowser';
					versionString: '1.1-baseline';
					loads: #('Core' );
					file: 'ConfigurationOfOmniBrowser';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.squeakCommon'. ];
			package: 'Metacello-Help' with: [
				spec requires: 'Help System'. ];
			package: 'OB-Metacello' with: [
				spec requires: #('OB' ). ];
			yourself.
		spec
			group: 'default' with: #('Metacello-Help');
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself.].
	spec for: #pharo do: [
		spec 
			project: 'ProfStef' with: [
				spec
					className: 'ConfigurationOfProfStef';
					versionString: '1.0-baseline';
					file: 'ConfigurationOfProfStef';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			yourself.
		spec
			package: 'Metacello-ProfStef' with: [
				spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox' ). ];
			package: 'Metacello-TestsProfStef' with: [
				spec requires: #('Metacello-ProfStef' ). ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo';
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsProfStef' );
			group: 'Tutorial' with: #('Metacello-ProfStef');
			yourself.].
	spec for: #'pharo1.2.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #'pharo1.3.x' do: [
		spec 
			package: 'Metacello-TestsMC' with: [
				spec includes: #( 'Metacello-Issue3758' )];
			package: 'Metacello-Issue3758' with: [
				spec requires:#( 'Metacello-TestsMC' )];
			yourself. ].
	spec for: #squeak do: [
		spec
			package: 'Metacello-Platform' with: 'Metacello-Platform.squeak';
			yourself.].
	spec for: #gemstone do: [
		spec
			project: 'Monticello' with: [
				spec
					className: 'ConfigurationOfGsMonticello';
					file: 'ConfigurationOfGsMonticello';
					repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
			yourself.
		spec 
			package: 'Metacello-Platform' with: [
				spec 
					file: 'Metacello-Platform.gemstone';
					requires: 'Monticello'];
			package: 'Metacello-TestsPlatform' with: [
				spec 
					requires: #('Metacello-Platform' );
					file: 'Metacello-TestsPlatform.gemstone'. ];
			yourself.
		spec
			group: 'Tests' with: #('Metacello-TestsPlatform' );
			yourself. ].! !

!ConfigurationOfMetacello methodsFor: 'baselines' stamp: 'dkh 9/25/2012 10:13'!
baseline10beta32: spec
    <version: '1.0-beta.32-baseline'>
    spec
        for: #'common'
        do: [ 
            spec blessing: #'baseline'.
            spec repository: 'http://seaside.gemstone.com/ss/metacello'.
            spec repository: 'http://www.squeaksource.com/metacello'.
            spec
                project: 'FileTree'
                    with: [ 
                            spec
                                className: 'ConfigurationOfFileTree';
                                versionString: '1.0-baseline';
                                repository: 'http://ss3.gemstone.com/ss/FileTree' ];
                project: 'Gofer'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGofer';
                                versionString: '1.0-baseline';
                                loads: #('Core');
                                repository: 'http://seaside.gemstone.com/ss/metacello' ];
                project: 'Gofer Tests' copyFrom: 'Gofer' with: [ spec loads: #('Tests') ];
                yourself.
            spec
                package: 'Metacello-Base';
                package: 'Metacello-ToolBox' with: [ spec requires: #('Metacello-Base' 'Metacello-Core') ];
                package: 'Metacello-Core'
                    with: [ 
                            spec
                                requires: 'Metacello-Base';
                                includes: #('Metacello-MC' 'Metacello-Platform') ];
                package: 'Metacello-FileTree' with: [ spec requires: #('Metacello-MC' 'FileTree') ];
                package: 'Metacello-GitHub' with: [ spec requires: #('Metacello-MC' 'Metacello-FileTree') ];
                package: 'Metacello-MC' with: [ spec requires: #('Metacello-Core' 'Gofer') ];
                package: 'Metacello-Platform' with: [ spec requires: #('Metacello-MC') ];
                package: 'Metacello-Reference' with: [ spec requires: #('Metacello-MC') ];
                package: 'Metacello-Tutorial' with: [ spec requires: #('Metacello-Core') ];
                package: 'Metacello-TestsCore' with: [ spec requires: #('Metacello-Core') ];
                package: 'Metacello-TestsMC'
                    with: [ 
                            spec
                                postLoadDoIt: #'testsMC10beta25PostLoadDoIt';
                                requires: #('Metacello-MC' 'Metacello-TestsCore' 'Gofer Tests' 'Metacello-ToolBox') ];
                package: 'Metacello-TestsReference' with: [ spec requires: #('Metacello-Reference') ];
                package: 'Metacello-TestsTutorial' with: [ spec requires: #('Metacello-Tutorial' 'Metacello-TestsMC') ];
                package: 'OB-Metacello'
                    with: [ spec requires: #('Metacello-Platform' 'Metacello-Core' 'Metacello-ToolBox') ];
                yourself.
            spec
                group: 'default' with: #('Metacello-Core' 'Metacello-ToolBox' 'Metacello-GitHub');
                group: 'batch' with: #('Metacello-Core' 'Metacello-GitHub');
                group: 'Base Configuration' with: #('Metacello-Base');
                group: 'Core' with: #('default');
                group: 'Tutorial' with: #('Metacello-Tutorial' 'Metacello-Reference');
                group: 'UI' with: #('OB-Metacello');
                group: 'TravisCI'
                    with:
                        #('Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
                group: 'Tests'
                    with:
                        #('default' 'Metacello-TestsCore' 'Metacello-TestsTutorial' 'Metacello-TestsMC' 'Metacello-TestsReference');
                yourself ].
    spec
        for: #'squeakCommon'
        do: [ 
            spec
                project: 'HelpSystem'
                    with: [ 
                            spec
                                className: 'ConfigurationOfHelpSystem';
                                versionString: #'1.0-baseline';
                                loads: #('Core');
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                project: 'OmniBrowser'
                    with: [ 
                            spec
                                className: 'ConfigurationOfOmniBrowser';
                                versionString: #'stable';
                                loads: #('Core');
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                project: 'OSProcess'
                    with: [ 
                            spec
                                className: 'ConfigurationOfOSProcess';
                                versionString: #'stable';
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-TestsPlatform'
                    with: [ 
                            spec
                                requires: #('Metacello-Platform');
                                file: 'Metacello-TestsPlatform.squeakCommon' ];
                package: 'Metacello-Help' with: [ spec requires: 'HelpSystem' ];
                package: 'OB-Metacello' with: [ spec requires: #('OmniBrowser') ];
                yourself.
            spec
                group: 'Tests' with: #('Metacello-TestsPlatform');
                group: 'TravisCI' with: #('Metacello-TestsPlatform');
                yourself ].
    spec
        for: #'pharo'
        do: [ 
            spec
                project: 'ProfStef'
                    with: [ 
                            spec
                                className: 'ConfigurationOfProfStef';
                                versionString: #'stable';
                                repository: 'http://www.squeaksource.com/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-ProfStef'
                    with: [ spec requires: #('Metacello-Core' 'ProfStef' 'Metacello-ToolBox') ];
                package: 'Metacello-TestsProfStef' with: [ spec requires: #('Metacello-ProfStef') ];
                package: 'Metacello-Platform'
                    with: [ 
                            spec
                                file: 'Metacello-Platform.pharo';
                                requires: #('OSProcess') ];
                yourself.
            spec
                group: 'Tests' with: #('Metacello-TestsProfStef');
                group: 'Tutorial' with: #('Metacello-ProfStef');
                yourself ].
    spec
        for: #'pharo2.x'
        do: [ 
            spec
                removeProject: 'OmniBrowser';
                removeProject: 'OSProcess'.
            spec package: 'Metacello-Platform' with: [ spec file: 'Metacello-Platform.pharo20' ] ].
    spec
        for: #'squeak'
        do: [ 
            spec yourself.
            spec
                package: 'Metacello-Platform'
                    with: [ 
                            spec
                                file: 'Metacello-Platform.squeak';
                                requires: #('OSProcess') ];
                yourself ].
    spec
        for: #'gemstone'
        do: [ 
            spec
                project: 'GsCore'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGsCore';
                                versionString: '0.247';
                                repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
                project: 'GsMonticello'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGsMonticello';
                                versionString: '0.242';
                                repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
                project: 'OmniBrowser'
                    with: [ 
                            spec
                                className: 'ConfigurationOfGsOB';
                                versionString: #'stable';
                                repository: 'http://seaside.gemstone.com/ss/MetacelloRepository' ];
                yourself.
            spec
                package: 'Metacello-GitHub' with: [ spec requires: #('GsCore') ];
                package: 'Metacello-MC' with: [ spec preLoadDoIt: #'gemstone10beta24PreLoadDoIt' ];
                package: 'Metacello-Platform'
                    with: [ 
                            spec
                                file: 'Metacello-Platform.gemstone';
                                postLoadDoIt: #'gemstone10beta311PostLoadDoIt';
                                requires: 'GsMonticello' ];
                package: 'Metacello-TestsPlatform'
                    with: [ 
                            spec
                                requires: #('Metacello-Platform');
                                file: 'Metacello-TestsPlatform.gemstone' ];
                package: 'OB-Metacello' with: [ spec requires: #('OmniBrowser') ];
                yourself.
            spec
                group: 'Tests' with: #('Metacello-TestsPlatform');
                group: 'TravisCI' with: #('Metacello-TestsPlatform');
                yourself ]! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 9/14/2012 16:31'!
bleedingEdge: spec
    <symbolicVersion: #'bleedingEdge'>
    spec for: #'common' version: '1.0-beta.31.1.5-baseline'! !

!ConfigurationOfMetacello methodsFor: 'accessing' stamp: 'dkh 6/12/2012 09:37:55.692'!
customProjectAttributes
    "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes "

    | attributes |
    attributes := #(#'Gofer-Core').
    Smalltalk
        at: #'SystemVersion'
        ifPresent: [ :cl | 
            (cl current version beginsWith: 'Pharo')
                ifTrue: [ 
                    (cl current perform: #'highestUpdate') <= 10504
                        ifTrue: [ attributes := #(#'Gofer') ] ] ].
    ^ attributes! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 9/10/2012 11:55'!
development: spec
    <symbolicVersion: #'development'>
    spec for: #'common' version: #'notDefined'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta24PreLoadDoIt
	"MetacelloGoferLoad>>addVersion: references an IV that no longer exists after version 292 of Metacello-MC"
	
	| wc ancestry versionNumber |
	wc := [((Smalltalk at: #GoferPackageReference) name: 'Metacello-MC') workingCopy] 
			on: Error 
			do: [:ex | ^self ].
	(ancestry := wc ancestry ancestors) isEmpty ifTrue: [ ^self ].
	versionNumber := (ancestry first name copyAfterLast: $.) asNumber.
	versionNumber > 292 ifTrue: [ ^self ].
	(Smalltalk at: #MetacelloGoferLoad)
		compileMethod: self gemstone10beta24PreLoadMethodString
		category: 'accessing'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta24PreLoadMethodString

	^'addVersion: aVersion

	model addVersion: version'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
gemstone10beta311PostLoadDoIt
	(Smalltalk at: #MetacelloGemStonePlatform) initialize! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/15/2012 16:54'!
metacelloPrimeRegistry
    (Smalltalk at: #'MetacelloProjectRegistration') perform: #'primeRegistryFromImage'! !

!ConfigurationOfMetacello methodsFor: 'accessing' stamp: 'dkh 9/16/2012 10:43'!
project
    ^ project
        ifNil: [ 
            "Bootstrap Metacello if it is not already loaded"
            self class ensureMetacello.
            project := (Smalltalk at: #'MetacelloMCProject') new projectAttributes: self customProjectAttributes.	"Create the Metacello project"
            (Smalltalk at: #'MetacelloVersionConstructor') on: self project: project.	"Construct the project"
            project loadType: #'linear'.	"change to #atomic if desired"
            project ]! !

!ConfigurationOfMetacello methodsFor: 'symbolic versions' stamp: 'dkh 9/14/2012 16:01'!
stable: spec
    <symbolicVersion: #'stable'>
    spec for: #'common' version: '1.0-beta.31.1.5'! !

!ConfigurationOfMetacello methodsFor: 'doits' stamp: 'dkh 6/12/2012 09:37:55.692'!
testsMC10beta25PostLoadDoIt
	"reset test resources"
	
	#( 
		MetacelloAlternateResource
		MetacelloAtomicConfigurationResource
		MetacelloAtomicMonticelloResource
		MetacelloConfigurationResource
		MetacelloMonticelloResource
	) do: [:className | Smalltalk at: className ifPresent: [:cls | cls reset ]]! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta0: spec
	<version: '1.0-beta.0' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Beta release introducing the shiny new API'.
		spec author: 'dkh'.
		spec timestamp: '10/9/2009 14:13'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.266';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.194';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.11';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.24';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.6';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta10: spec
	<excludedValidationIssues: #('1.0-beta.10' #(noVersionSpecified))>
	<version: '1.0-beta.10' imports: #('1.0-beta.5-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- GemStone-specific mods
- improve error message for missing import
- fix a couple of bugs in spawn new version
- if versionString is not specified in project reference, use #latestVersion of the project
- ''Update Package Method'' command updates the versionString for project reference to #currentVersion of the project
- ''Spawn New Version'' command spawns entry for proejct reference using #currentVersion of the project
- latest version of configuration package is loaded if the project reference refers to a version whose blessing is #development
- refactor #saveProject
- add #transact: to platform to support GemStone optional transactions
- define querying protocol (public access)
- use literal arrays instead of array constructors _everywhere_
- clean up printing
- refine querying API
- extend tutorial to cover querying API
'.
		spec author: 'dkh'.
		spec timestamp: '10/25/2009 11:34'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.70';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.285';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.222';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.29';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta11: spec
	<version: '1.0-beta.11' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- pick up latest Gofer package
- fix a project version loading bug
- printing fix
- fix an update packages bug
- adjust working version package name calculation
- fix current version package name calculation (http://code.google.com/p/metacello/issues/detail?id=4)
- doits bugfix
- fix a project reference project package bug
- add ''Load Latest Packages'' OB command
- remove Samples group
- save packages fix
- must be able to load packages that use directory repositories
- GemStone/GLASS support'.
		spec author: 'dkh'.
		spec timestamp: '10/31/09 11:03:31'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.294';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.239';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.32';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.1';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta12: spec
	<version: '1.0-beta.12' imports: #('1.0-beta.11-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '-convert to using ConfigurationOfMetacello convention
- fix updateRepositories bug (update repository for loaded packages only)
- #repositoryFor:from: ... more GLASS support
- record last version loaded and list of packages loaded for each configuration (optional)
- use last list of packages loaded last when loading packages using tools
- improve promptForVersion algorithm to show current version and reduce version list to logical choices
- fix version number bug when version is empty. add tests
'.
		spec author: 'dkh'.
		spec timestamp: '11/03/09 11:07:27'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.76';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.295';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.245';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta13: spec
	<version: '1.0-beta.13' imports: #('1.0-beta.13-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix a bug in current version algorithm
- improve current version algorithm
- pick up latest Gofer
'.
		spec author: 'dkh'.
		spec timestamp: '11/5/2009 15:46'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.77';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.300';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.249';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.7'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta14: spec
	<version: '1.0-beta.14' imports: #('1.0-beta.14-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- improve handling of #development project references. Loader is responsible for ensuring that #development projects have latest package loaded.
- use latest Gofer
- skip automatic loading of packages when working copy #needsSaving
- better loop termination logic for packageSpecsInLoadOrder
- fix logic for loading latest version of a project when versionString is not set (use latest, then last version)
- collect repositories from just the packages (ignoring projects) ... affects load latest logic
- fix #promptForVersion: ... include #development versions in listing
- GemStone attributes, now may include: #gemstone #''gs2.x'' #''gs2.3.x'' #''gs2.4.x'' and #''gs3.x'' for finer grainded resolution of Stone version
- fix a package loading logic bug found by Doru (loading latest)'.
		spec author: 'dkh'.
		spec timestamp: '11/16/2009 15:02'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.256';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta15: spec
	<version: '1.0-beta.15' imports: #('1.0-beta.14-baseline' )>

	spec for: #common do: [
		spec blessing: #development.
		spec description: '- fix ''Spawn New Version'' command
- tweak packageSpec shortcut printing - fine tune use of #overrides:'.
		spec author: 'dkh'.
		spec timestamp: '11/21/2009 11:49'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.258';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta16: spec
	<version: '1.0-beta.16' imports: #('1.0-beta.16-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- put Gofer package in Metacello repository'.
		spec author: 'dkh'.
		spec timestamp: '12/01/09 16:22:42'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.302';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.259';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.18';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.37';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.4';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.11';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #'gemstone' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #'pharo' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta17: spec
	<version: '1.0-beta.17' imports: #('1.0-beta.17-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix a branch name problem for working copies
- fine tune the ''Update Package Methods'' algorithm
- fix Issue 3: http://code.google.com/p/metacello/issues/detail?id=3 ''Save Packages'' save new
- fix Issue 12: http://code.google.com/p/metacello/issues/detail?id=12 Wait cursor during load
- fix Issue 14: http://code.google.com/p/metacello/issues/detail?id=14 Ftp repository for Pharo & Squeak
- fix Issue 19: http://code.google.com/p/metacello/issues/detail?id=19 Bug in Spawn New Version
'.
		spec author: 'dkh'.
		spec timestamp: '12/9/2009 11:13'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.83';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.306';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.268';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.19';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.38';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.5';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.2';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.12';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.9'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.9'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.3'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta18: spec
	<version: '1.0-beta.18' imports: #('1.0-beta.18-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- implement MetacelloVersion>>isPossibleBaseline
- fix currentVersion when no packages or projects are in play
- fix a Spawn New Version bug
- allow for a nil #versionString spec in projects
- fix Issue 14: http://code.google.com/p/metacello/issues/detail?id=14 Ftp repository for Squeak only
- fix Issue 18: http://code.google.com/p/metacello/issues/detail?id=18 #linear default loadType
- fix Issue 21: http://code.google.com/p/metacello/issues/detail?id=21 optional blessing for Spawn New Version
- fix Issue 22: http://code.google.com/p/metacello/issues/detail?id=22 Better filter for Branch blessing and lastVersion
- fix Issue 23: http://code.google.com/p/metacello/issues/detail?id=23 Use Gofer batch commit for Save Packages
- fix Issue 26: http://code.google.com/p/metacello/issues/detail?id=26 New version of Gofer breaks Metacello
- port to latest version of Gofer (Gofer-lr.109)'.
		spec author: 'dkh'.
		spec timestamp: '12/29/2009 16:17'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.109';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.311';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.281';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.20';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.6';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.15';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.4'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.235'.
		spec 
			package: 'Gofer' with: 'Gofer-dkh.105';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.279';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.10'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.9'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta191: spec
	<excludedValidationIssues: #('1.0-beta.19.1' #(noVersionSpecified))>
	<version: '1.0-beta.19.1' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 39: http://code.google.com/p/metacello/issues/detail?id=39 "WB at end of ConfigurationOfPharo load"
'.
		spec author: 'dkh'.
		spec timestamp: '1/8/2010 14:45'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.292';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.26';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.11'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta19: spec
	<excludedValidationIssues: #('1.0-beta.19' #(noVersionSpecified))>
	<version: '1.0-beta.19' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- "Pure" Refactoring of MetacelloVersionConstructor>>on: (Danie Roux)
- fix Issue 7: http://code.google.com/p/metacello/issues/detail?id=7 "#repositoryOverrides: should be in MetacelloMCVersion"
- fix Issue 13: http://code.google.com/p/metacello/issues/detail?id=13 "more than one repository per package"
- fix Issue 16: http://code.google.com/p/metacello/issues/detail?id=16 "version level predoit/postdoit"
- fix Issue 20: http://code.google.com/p/metacello/issues/detail?id=20 "validation in #postLoadDoIt:/#preLoadDoit:"
- fix Issue 28: http://code.google.com/p/metacello/issues/detail?id=28 "supplyingAnswers: attribute for packages"
- fix Issue 30: http://code.google.com/p/metacello/issues/detail?id=30 "Imported version names"
- fix Issue 33: http://code.google.com/p/metacello/issues/detail?id=33 "ensureMetacello should do full bootstrap"
- fix Issue 38: http://code.google.com/p/metacello/issues/detail?id=38 "Metacello load fails on Squeak"
- port Gofer-lr.109 to GemStone
- stop caching packages in Pharo ... can cause trouble if repository off-line
- fix problems with GemStone Metacello when runnng without OB
- make error handler for #do:displaying: a little more specific 
- fix a problem when a second version of a package is being requested during atomic load. Must override with newer package.
- run with pre and post 10504 Pharo images
'.
		spec author: 'dkh'.
		spec timestamp: '1/8/2010 11:12'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.292';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-dkh.17';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.26';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.10'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta1: spec
	<version: '1.0-beta.1' imports: #('1.0-beta.0-baseline')>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: 'Bugfixes:
- change base version name for spawn method
- make sure author and timestamp included by spawn 
- fix file duplication for spawn method'.
		spec author: 'dkh'.
		spec timestamp: '10/10/2009 14:58'.
		spec 
			package: 'Gofer' with: 'Gofer-lr.64';
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.268';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.196';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.12';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.25';
			package: 'Metacello-ConfigTests' with: 'Metacello-ConfigTests-dkh.7';
			package: 'Metacello-ReferenceTests' with: 'Metacello-ReferenceTests-dkh.1'.].
	spec for: #gemstone do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.4'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.7'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.1'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta20: spec
	<excludedValidationIssues: #('1.0-beta.20' #(noVersionSpecified))>
	<version: '1.0-beta.20' imports: #('1.0-beta.19-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- tests for nested #for:do: statements
- fix Issue 40: http://code.google.com/p/metacello/issues/detail?id=40 "Tight package/repository coordination lost"
- take full advantage of Gofer repository caching
- more tests to ensure expected loading behavior
- typos fixed in Tutorial (Torsten)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/14/2010 09:45'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-dkh.319';
			package: 'Metacello-MC' with: 'Metacello-MC-dkh.296';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-dkh.29';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec package: 'Gofer-Core' with: 'Gofer-Core-AdrianLienhard.114'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.109'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-dkh.11'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-dkh.11'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta21: spec
	<version: '1.0-beta.21' imports: #('1.0-beta.21-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix new tests so that they run on GemStone and don''t collide with existing packages
- fix Issue 41: http://code.google.com/p/metacello/issues/detail?id=41 "Trouble with nested ProgressInitiationException in certain circumstances"
- fix Issue 42: http://code.google.com/p/metacello/issues/detail?id=42 "ConfigurationOfSeaside* should use supplyingAnswers:"
- fix Issue 43: http://code.google.com/p/metacello/issues/detail?id=43 "Eliminate use of #versionInfoFor:from:do: "
- Metacello now uses Gofer for all of its interactions with Monticello (a few pockets of workingCopy still exist:)
- pick up latest Gofer-Core-lr.115 and Gofer-Tests
- some more version caching for speed
- better workingCopy resolution for MetacelloCachingGoferResolvedReference
- adjust tests - no longer inheriting pragmas ... too expensive
- introduce valueSupplyingMetacelloAnswers: to work around Pharo Issue 1824 http://code.google.com/p/pharo/issues/detail?id=1824
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/16/2010 12:47'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.321';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.302';
			package: 'Metacello-Reference' with: 'Metacello-Reference-dkh.26';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-dkh.11';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.34';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'Gofer-Core' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-lr.115';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.113'.].
	spec for: #Gofer do: [
		spec package: 'Gofer' with: 'Gofer-lr.113'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.12'.].
	spec for: #squeakCommon do: [
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.12'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta22: spec
	<version: '1.0-beta.22' imports: #('1.0-beta.22-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 36: http://code.google.com/p/metacello/issues/detail?id=36 "Use ConfigurationOfOB for Metacello"
- fix Issue 49: http://code.google.com/p/metacello/issues/detail?id=49 "occassional load of older versions of projects"
- fix Issue 52: http://code.google.com/p/metacello/issues/detail?id=52 "preload/postload for groups and projects"
- MetacelloMCVersion>>resolveToLoadableSpecs: added to supplement query API
- support for Metaceller
- fix a bug in MetacelloMCProjectSpec>>resolveToAllPackagesIn:visited: when the project spec doesn''t have a versionString specified
- ProfStef tutorial (MetacelloCreateConfigurationTutorial)
- latest Gofer (Gofer-Core-lr.116 and Gofer-Tests-lr.115)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/25/2010 14:19'.
		spec 
			project: 'Gofer Core' with: '1.0';
			project: 'Gofer Tests' with: '1.0'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.328';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.312';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-dkh.3';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.43';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.13'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.12'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.4'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta23: spec
	<version: '1.0-beta.23' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- port to Squeak3.9.1-final-7075, Squeak3.10.2-7179-basic, Squeak3.10.2-Trunk-091128 and Squeak3.11-8931-alpha
- add #unloadMetacello to MetacelloConfigTemplate
- fix Issue25 : http://code.google.com/p/metacello/issues/detail?id=25 "currentVersion cache is too sticky ..."
- full frontal assault on findCurrentVersion and currentVersion algorithms ... corner implementation with a brigage of tests
- fix a bug in GoferResolvedReference>>compare:using: related to branch comparison found during frontal assault!!
- version #versionStatus provides additional info for using currentVersion
- deleted a bunch of methods (redundant,  confusing, not interesting and no longer used):
  - MetacelloVersion>>isCurrentCovering:
  - MetacelloProject>>currentVersionComparison:to:covering:
  - MetacelloProject>>currentVersionCovering:
  - MetacelloProject>>findCurrentVersion
  - MetacelloMCVersionSpec>>isCurrentCovering:
  - MetacelloMCVersionSpec>>isPartiallyCurrentAgainst:
  - MetacelloMCProjectSpec>>isCurrent
  - MetacelloProjectReferenceSpec>>compareVersionForLoad:using:
  - MetacelloAbstractPackageSpec>>compareVersionForLoad:using:
  - MetacelloMCVersionSpec>>isPartiallyCurrentFor:
  - MetacelloProjectReferenceSpec>>isPartiallyCurrentUsing:
  - MetacelloMCProjectSpec>>comparePartialVersion:using:
  - MetacelloProject>>partialVersionComparison:to:covering:
  - MetacelloMCProject>>projectPackage
  - MetacelloMCVersionSpec>>currentVersionComparison:covering:
  - MetacelloMCVersion>>currentVersionComparison:covering:
  - MetacelloVersion>>currentVersionComparison:covering:
  - MetacelloProjectReferenceSpec>>isPartiallyCurrentUsing:
  - MetacelloMCProjectSpec>>compareVersionForLoad:using:
  - MetacelloMCVersionSpec>>isCurrent
  - MetacelloPackageSpec>>compareVersion:using:
  - MetacelloPackageSpec>>isCurrentUsing:
  - MetacelloMCProjectSpec>>compareVersion:using:
  - MetacelloMCProjectSpec>>isCurrentUsing:
  - MetacelloAbstractPackageSpec>>isCurrentUsing:
  - MetacelloGroupSpec>>isCurrentUsing:
  - MetacelloProjectReferenceSpec>>isCurrentUsing:
  - MetacelloProject>>currentVersionComparison:to:
  - MetacelloVersion>>isCurrent
  - MetacelloVersionSpec>>isCurrent
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/10/10 09:56:41'.
		spec 
			project: 'Gofer Core' with: '1.0';
			project: 'Gofer Tests' with: '1.0'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.348';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.332';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.14'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta2401: spec
	<version: '1.0-beta.24.0.1' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'patched'.
		spec description: 'picked up from patched 1.0-beta.24 from allen for GLASS 1.0-beta.7.1 on GemStone 3.0'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '7/16/2010 12:56'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-ao.350';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.334';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta241: spec
	<version: '1.0-beta.24.1' imports: #('1.0-beta.22-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 66: http://code.google.com/p/metacello/issues/detail?id=66 "loading latest broken by new code in 1.0-beta.24"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/17/2010 11:26'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-Dalehenrichs.349';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.Issue66.335';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta24: spec
	<version: '1.0-beta.24' imports: #('1.0-beta.22-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'beta'.
		spec description: '- fix a bug in MetacelloMCProjectSpec>>compareCurrentVersion:targetVersionStatus:using: related when calculating current version against a non-standard loader
- tweak the loader API a bit for GemStone (performance improvements)
- tweak transcript info for atomic load
- start using Gofer 1.0.1
- adjust conditions that lead to a load conflict error
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/12/10 14:44:01'.
		spec 
			project: 'Gofer Core' with: '1.0.1';
			project: 'Gofer Tests' with: '1.0.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-Dalehenrichs.349';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.335';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.28';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-tbn.19';
			package: 'OB-Metacello' with: 'OB-Metacello-dkh.40';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.13';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.66';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-dkh.5'.].
	spec for: #'gemstone' do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt ];
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.15'.].
	spec for: #'squeakCommon' do: [
		spec project: 'OB' with: '1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #'pharo' do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.13'.].
	spec for: #'squeak' do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta251: spec
	<version: '1.0-beta.25.1' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 67: http://code.google.com/p/metacello/issues/detail?id=67 "blessing not generated by MetacelloVersionConstructor>>spawnPackageMethodIn: category: named: sourceVersion: targetVersion: blessing:"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/23/2010 19:16'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.360';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.386';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.90';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta25: spec
	<version: '1.0-beta.25' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- pick up Gofer 1.0.2
- fix Issue 10: http://code.google.com/p/metacello/issues/detail?id=10 "''save packages'' should recurse through projects"
- fix Issue 24: http://code.google.com/p/metacello/issues/detail?id=24 "Gofer #fetch support"
- fix Issue 31: http://code.google.com/p/metacello/issues/detail?id=31 "Handle boundary between #atomic and #linear loads ..."
- fix Issue 32: http://code.google.com/p/metacello/issues/detail?id=32 "Connect repositories as MCServerDirectory rather than MCDirectory"
- fix Issue 48: http://code.google.com/p/metacello/issues/detail?id=48 "Should have #loadReport message for loader..."
- fix Issue 56: http://code.google.com/p/metacello/issues/detail?id=56 "save configurtion that uses Gofer>>commit:"
- fix Issue 57: http://code.google.com/p/metacello/issues/detail?id=57 "specificy method category for version category in Metacello version constructor"
- fix Issue 58: http://code.google.com/p/metacello/issues/detail?id=58 "make #file: optional in project reference specification"
- fix Issue 59: http://code.google.com/p/metacello/issues/detail?id=59 "repository overrides should be used for MetacelloPackageSpec>>load"
- fix Issue 60: http://code.google.com/p/metacello/issues/detail?id=60 "bypass progress bars...."
- fix Issue 64: http://code.google.com/p/metacello/issues/detail?id=64 "update package methods has extra file entry"
- fix Issue 66: http://code.google.com/p/metacello/issues/detail?id=66 "loading latest broken by new code in 1.0-beta.24" [MERGE]
- #fetch and #fetch: added to MetacelloMcVersion. #fetch and #fetch: correspond to #load and #load: but only download the mcz files to a cacheRepository (controlled by version #loadPolicy)
- #fetchProject, #fetchProject:, #updateProject: added to support direct fetch of a project (ala #updateProject)
- implement version #record/#record:
- implement version #silently: for Issue 60
- implement non-interactive commit support using gofer: MetacelloMCProject>>goferCommitProject:, MetacelloPackageSpec>>goferCommitPackage:
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/23/2010 15:24'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.358';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.386';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.90';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta261: spec
	<version: '1.0-beta.26.1' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix and test coverage for bug involving a postload doit with linear load nested inside an atomic load
- when loading a project reference, do not load mcz files that are older than the currently loaded mcz files (implicit version request). Older files will be loaded if directly referenced from the project being loaded (explicit version request).
- add RETRY logic to handle HTTP droppage
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/12/2010 12:19'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.404';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.98';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta262: spec
	<version: '1.0-beta.26.2' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- Pharo1.1 compat for OB-Metacello
- fix Issue 77: http://code.google.com/p/metacello/issues/detail?id=77 "later version of Project reference not loaded after old version already loaded"
- add MetacelloFetchingMCSpecLoader>>printOn: that prints out loadDirective, thus restoring correct #printOn: behavior for MetacelloNullRecordingMCSpecLoader since tutorial depends upon it..
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/21/2010 16:26 '.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.407';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.99';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta263: spec
	<version: '1.0-beta.26.3' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix Issue 81: http://code.google.com/p/metacello/issues/detail?id=81 "wrong mcz file can be loaded when mcz file has Monticello dependencies"
- fix Issue 82: http://code.google.com/p/metacello/issues/detail?id=82 "Metacello and (Windows) file repositories"
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/11/2010 11:26'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-tbn.362';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.409';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.30';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.15';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.102';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta26: spec
	<version: '1.0-beta.26' imports: #('1.0-beta.25-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- put comment in MetacelloMCProject>>#updateProject to warn about refreshing instance.
- helper messages: #cacheRepository: and #ignoreImage: added to MetacelloMCVersion
- refactor directive hierarchy for post/pre Load directives add #postLoadDo: and #preLoadDo: to round out API
- clean up null recording loader with respect to fetch and post/pre load doits
- directives weren''t being created correctly for post/pre load doits on packages .... now they are
- ConfigurationOfMetacello class>>alternateEnsureMetacello to be used if GemSource repository is inaccessible
- assorted tests
- #fetchPackage: added to MetacelloPackageSpec taking a MetacelloLoaderPolicy like #fetchProject: for MetacelloMCProjectSpec
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '4/12/2010 14:27'.
		spec 
			project: 'Gofer Core' with: '1.0.2';
			project: 'Gofer Tests' with: '1.0.2'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.361';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.393';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.29';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.55';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.14';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.92';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec project: 'OB' with: '1.1.1'.
		spec package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !

!ConfigurationOfMetacello methodsFor: 'versions' stamp: 'dkh 6/12/2012 09:37:55.692'!
version10beta271: spec
	<version: '1.0-beta.27.1' imports: #('1.0-beta.27-baseline' )>

	spec for: #common do: [
		spec blessing: #beta.
		spec description: '- fix for Issue 86 (http://code.google.com/p/metacello/issues/detail?id=86) "project references that are supersets of a loaded project reference appear to be partially loaded"'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/24/2010 20:06'.
		spec 
			project: 'Gofer Core' with: '1.0.2.1';
			project: 'Gofer Tests' with: '1.0.2.1'.
		spec 
			package: 'Metacello-Core' with: 'Metacello-Core-DaleHenrichs.363';
			package: 'Metacello-MC' with: 'Metacello-MC-DaleHenrichs.417';
			package: 'Metacello-Reference' with: 'Metacello-Reference-DaleHenrichs.31';
			package: 'Metacello-Tutorial' with: 'Metacello-Tutorial-DaleHenrichs.20';
			package: 'OB-Metacello' with: 'OB-Metacello-DaleHenrichs.56';
			package: 'Metacello-TestsReference' with: 'Metacello-TestsReference-DaleHenrichs.16';
			package: 'Metacello-TestsCore' with: 'Metacello-TestsCore-DaleHenrichs.8';
			package: 'Metacello-TestsMC' with: 'Metacello-TestsMC-DaleHenrichs.106';
			package: 'Metacello-TestsTutorial' with: 'Metacello-TestsTutorial-DaleHenrichs.7'.].
	spec for: #gemstone do: [
		spec project: 'Monticello' with: '0.236'.
		spec 
			package: 'Metacello-MC' with: [
				spec preLoadDoIt: #gemstone10beta24PreLoadDoIt. ];
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.gemstone-DaleHenrichs.1';
			package: 'Metacello-Platform' with: 'Metacello-Platform.gemstone-DaleHenrichs.16'.].
	spec for: #squeakCommon do: [
		spec 
			project: 'OB' with: '1.1.4';
			project: 'Help System' with: '1.1'.
		spec 
			package: 'Metacello-TestsPlatform' with: 'Metacello-TestsPlatform.squeakCommon-dkh.2';
			package: 'Metacello-Help' with: 'Metacello-Help-tbn.3'.].
	spec for: #pharo do: [
		spec project: 'ProfStef' with: '1.0'.
		spec 
			package: 'Metacello-ProfStef' with: 'Metacello-ProfStef-DaleHenrichs.2';
			package: 'Metacello-Platform' with: 'Metacello-Platform.pharo-DaleHenrichs.16'.].
	spec for: #squeak do: [
		spec package: 'Metacello-Platform' with: 'Metacello-Platform.squeak-dkh.5'.].! !
